@@ -1,4 +1,4 @@
-package t::TestYAML;
+package TestYAML;
 
 BEGIN { $ENV{PERL_DL_NONLAZY} = 0 }
 
@@ -12,6 +12,7 @@ sub import {
     plan @_;
 
     *::ok        = *ok;
+    *::like      = *like;
     *::is        = *is;
     *::is_deeply = *is_deeply;
     *::roundtrip = *roundtrip;
